summaryrefslogtreecommitdiffstats
path: root/kodo
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:58 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-25 00:37:58 -0600
commit9ea931fb1bda0802797c1d38fd903b5451b91a5a (patch)
tree52871b68f40404504f789e2abefc24080510e51e /kodo
parent2178da111f72dc574457d5242d120b4d10ea5edd (diff)
downloadtdetoys-9ea931fb1bda0802797c1d38fd903b5451b91a5a.tar.gz
tdetoys-9ea931fb1bda0802797c1d38fd903b5451b91a5a.zip
Rename KCModule, KConfig, KIO, KServer, and KSocket to avoid conflicts with KDE4
Diffstat (limited to 'kodo')
-rw-r--r--kodo/kodometer.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kodo/kodometer.cpp b/kodo/kodometer.cpp
index f09e21e..fc1b364 100644
--- a/kodo/kodometer.cpp
+++ b/kodo/kodometer.cpp
@@ -550,13 +550,13 @@ TQString Kodometer::FormatDistance(double &dist, Units unit)
}
/*
* Use KConfig to read all settings from disk. Note that whatever
* happens here overrides the defaults, but there's not much
* sanity-checking.
*/
void Kodometer::readSettings(void)
{
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
config->setGroup("Settings");
UseMetric = config->readNumEntry("UseMetric", false);
@@ -575,7 +575,7 @@ void Kodometer::readSettings(void)
*/
void Kodometer::saveSettings(void)
{
- KConfig* config = TDEGlobal::config();
+ TDEConfig* config = TDEGlobal::config();
config->setGroup("Settings");
config->writeEntry("UseMetric", UseMetric);
@@ -550,13 +550,13 @@ TQString Kodometer::FormatDistance(double &dist, Units unit)
}
/*
- * Use KConfig to read all settings from disk. Note that whatever
+ * Use TDEConfig to read all settings from disk. Note that whatever
* happens here overrides the defaults, but there's not much
* sanity-checking.